@@ -5,7 +5,7 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build flex
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 sub bin_dir
@@ -13,7 +13,7 @@ sub bin_dir
   my($class) = @_;
   if($class->install_type('system'))
   {
-    my $path = $class->config('bison_system_path');
+    my $path = $class->config('flex_system_path');
     return ($path) if $path;
   }
 
@@ -34,7 +34,7 @@ Alien::flex - Find or build flex
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
